@@ -20,6 +20,7 @@
 ### MA 02110-1301, USA
 
 
+
 logLimits <- function(lim, base)
 {
     if (is.list(lim))
@@ -96,6 +97,18 @@ as.factorOrShingle <- function(x, subset = TRUE, drop = FALSE)
 
 
 
+## this is a generalization of range(x), used as the xlim/ylim
+## components of prepanel functions.  It should deals with factors,
+## numerics, and date-time classes.
+scale.limits <- function(x)
+{
+    if (is.factor(x)) levels(x)
+    else if (is.numeric(x)) range(x, finite = TRUE)
+    else range(x, na.rm = TRUE)
+}
+
+
+
 
 ## update elements of a list recursively. Used in updating trellis or
 ## lattice settings using trellis.par.set and lattice.options
